==> ojalgo_53.3.0+ds.orig.tar.xz: ojAlgo-53.3.0/src/test/java/org/ojalgo/array/SegmentedArrayTest.java <==
/*
 * Copyright 1997-2024 Optimatika
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.ojalgo.array;

import org.junit.jupiter.api.Test;

/**
 * AbstractArrayTest
 *
 * @author apete
 */
public class SegmentedArrayTest extends ArrayTests {

    @Test
    public void testRandomSetAndGetBackPrimitive64() {

        final long tmpCount = 5000L;

        final SegmentedArray<Double> tmpArray = ArrayR064.FACTORY.makeSegmented(tmpCount);

        ArrayTests.doTestRandomSetAndGetBack(tmpArray, tmpCount);
    }

    @Test
    public void testVeryLargeRandomSetAndGetBackBasic() {

        final long tmpCount = Long.MAX_VALUE;

        final BasicArray<Double> tmpArray = new BasicArray.Factory<>(ArrayR064.FACTORY).make(tmpCount);

        ArrayTests.doTestRandomSetAndGetBack(tmpArray, tmpCount);
    }

}

==> ojalgo_56.0.0+ds.orig.tar.xz: ojAlgo-56.0.0/src/test/java/org/ojalgo/array/SegmentedArrayTest.java <==
/*
 * Copyright 1997-2025 Optimatika
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.ojalgo.array;

import org.junit.jupiter.api.Test;

/**
 * AbstractArrayTest
 *
 * @author apete
 */
public class SegmentedArrayTest extends ArrayTests {

    @Test
    public void testRandomSetAndGetBackPrimitive64() {

        long count = 5000L;

        BasicArray<Double> array = new BasicArray.Factory<>(ArrayR064.FACTORY).make(count);

        ArrayTests.doTestRandomSetAndGetBack(array, count);
    }

    @Test
    public void testVeryLargeRandomSetAndGetBackBasic() {

        long count = Integer.MAX_VALUE;

        BasicArray<Double> array = new BasicArray.Factory<>(ArrayR064.FACTORY).make(count);

        ArrayTests.doTestRandomSetAndGetBack(array, count);
    }

}
